"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.video_pb2
import yandex.cloud.video.v1.video_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class VideoServiceStub:
    """Video management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.GetVideoRequest,
        yandex.cloud.video.v1.video_pb2.Video,
    ]
    """Get the specific video."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.ListVideoRequest,
        yandex.cloud.video.v1.video_service_pb2.ListVideoResponse,
    ]
    """List videos for channel."""

    BatchGet: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideosRequest,
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideosResponse,
    ]
    """Batch get videos in specific channel."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.CreateVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create video."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.UpdateVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update video."""

    Transcode: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.TranscodeVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Transcode video."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.DeleteVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete video."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.BatchDeleteVideosRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete videos."""

    PerformAction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.PerformVideoActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the video."""

    GetPlayerURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLRequest,
        yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLResponse,
    ]
    """Get player url."""

    BatchGetPlayerURLs: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsRequest,
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsResponse,
    ]
    """Batch get player urls."""

    GetManifests: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsRequest,
        yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsResponse,
    ]
    """Get manifest urls."""

class VideoServiceAsyncStub:
    """Video management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.GetVideoRequest,
        yandex.cloud.video.v1.video_pb2.Video,
    ]
    """Get the specific video."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.ListVideoRequest,
        yandex.cloud.video.v1.video_service_pb2.ListVideoResponse,
    ]
    """List videos for channel."""

    BatchGet: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideosRequest,
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideosResponse,
    ]
    """Batch get videos in specific channel."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.CreateVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create video."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.UpdateVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update video."""

    Transcode: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.TranscodeVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Transcode video."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.DeleteVideoRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete video."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.BatchDeleteVideosRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete videos."""

    PerformAction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.PerformVideoActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the video."""

    GetPlayerURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLRequest,
        yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLResponse,
    ]
    """Get player url."""

    BatchGetPlayerURLs: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsRequest,
        yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsResponse,
    ]
    """Batch get player urls."""

    GetManifests: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsRequest,
        yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsResponse,
    ]
    """Get manifest urls."""

class VideoServiceServicer(metaclass=abc.ABCMeta):
    """Video management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.GetVideoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.video_pb2.Video, collections.abc.Awaitable[yandex.cloud.video.v1.video_pb2.Video]]:
        """Get the specific video."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.ListVideoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.video_service_pb2.ListVideoResponse, collections.abc.Awaitable[yandex.cloud.video.v1.video_service_pb2.ListVideoResponse]]:
        """List videos for channel."""

    @abc.abstractmethod
    def BatchGet(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.BatchGetVideosRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.video_service_pb2.BatchGetVideosResponse, collections.abc.Awaitable[yandex.cloud.video.v1.video_service_pb2.BatchGetVideosResponse]]:
        """Batch get videos in specific channel."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.CreateVideoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create video."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.UpdateVideoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update video."""

    @abc.abstractmethod
    def Transcode(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.TranscodeVideoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Transcode video."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.DeleteVideoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete video."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.BatchDeleteVideosRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Batch delete videos."""

    @abc.abstractmethod
    def PerformAction(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.PerformVideoActionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Perform an action on the video."""

    @abc.abstractmethod
    def GetPlayerURL(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.video_service_pb2.GetVideoPlayerURLResponse]]:
        """Get player url."""

    @abc.abstractmethod
    def BatchGetPlayerURLs(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.video_service_pb2.BatchGetVideoPlayerURLsResponse]]:
        """Batch get player urls."""

    @abc.abstractmethod
    def GetManifests(
        self,
        request: yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.video_service_pb2.GetVideoManifestsResponse]]:
        """Get manifest urls."""

def add_VideoServiceServicer_to_server(servicer: VideoServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/sqlserver/v1/resource_preset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/sqlserver/v1/resource_preset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.mdb.sqlserver.v1 import resource_preset_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_resource__preset__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/mdb/sqlserver/v1/resource_preset_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x33yandex/cloud/mdb/sqlserver/v1/resource_preset.proto\x1a\x1dyandex/cloud/validation.proto\"<\n\x18GetResourcePresetRequest\x12 \n\x12resource_preset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"Z\n\x1aListResourcePresetsRequest\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8a\x01\n\x1bListResourcePresetsResponse\x12G\n\x10resource_presets\x18\x01 \x03(\x0b\x32-.yandex.cloud.mdb.sqlserver.v1.ResourcePreset\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=1002\xf2\x02\n\x15ResourcePresetService\x12\xad\x01\n\x03Get\x12\x37.yandex.cloud.mdb.sqlserver.v1.GetResourcePresetRequest\x1a-.yandex.cloud.mdb.sqlserver.v1.ResourcePreset\">\x82\xd3\xe4\x93\x02\x38\x12\x36/mdb/sqlserver/v1/resourcePresets/{resource_preset_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.mdb.sqlserver.v1.ListResourcePresetsRequest\x1a:.yandex.cloud.mdb.sqlserver.v1.ListResourcePresetsResponse\")\x82\xd3\xe4\x93\x02#\x12!/mdb/sqlserver/v1/resourcePresetsBv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSRSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.resource_preset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSRSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _globals['_GETRESOURCEPRESETREQUEST'].fields_by_name['resource_preset_id']._loaded_options = None
  _globals['_GETRESOURCEPRESETREQUEST'].fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTRESOURCEPRESETSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTRESOURCEPRESETSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0028\0226/mdb/sqlserver/v1/resourcePresets/{resource_preset_id}'
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/mdb/sqlserver/v1/resourcePresets'
  _globals['_GETRESOURCEPRESETREQUEST']._serialized_start=208
  _globals['_GETRESOURCEPRESETREQUEST']._serialized_end=268
  _globals['_LISTRESOURCEPRESETSREQUEST']._serialized_start=270
  _globals['_LISTRESOURCEPRESETSREQUEST']._serialized_end=360
  _globals['_LISTRESOURCEPRESETSRESPONSE']._serialized_start=363
  _globals['_LISTRESOURCEPRESETSRESPONSE']._serialized_end=501
  _globals['_RESOURCEPRESETSERVICE']._serialized_start=504
  _globals['_RESOURCEPRESETSERVICE']._serialized_end=874
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.containerregistry.v1.image_pb2
import yandex.cloud.containerregistry.v1.lifecycle_policy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___GetLifecyclePolicyRequest = GetLifecyclePolicyRequest

@typing.final
class ListLifecyclePoliciesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the lifecycle policy."""
    repository_id: builtins.str
    """Repository of the lifecycle policy."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns 
    a [ListLifecyclePoliciesResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListLifecyclePoliciesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters lifecycle policy resources listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [LifecyclePolicy.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    order_by: builtins.str
    """Sorting the list by [LifecyclePolicy.name], [LifecyclePolicy.created_at] and [LifecyclePolicy.status] fields.
    The default sorting order is ascending.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        repository_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["id", b"id", "registry_id", b"registry_id", "repository_id", b"repository_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "id", b"id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "registry_id", b"registry_id", "repository_id", b"repository_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["registry_id", "repository_id"] | None: ...

global___ListLifecyclePoliciesRequest = ListLifecyclePoliciesRequest

@typing.final
class ListLifecyclePoliciesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListLifecyclePoliciesRequest.page_size], use `next_page_token` as the value
    for the [ListLifecyclePoliciesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def lifecycle_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy]:
        """List of lifecycle policies."""

    def __init__(
        self,
        *,
        lifecycle_policies: collections.abc.Iterable[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policies", b"lifecycle_policies", "next_page_token", b"next_page_token"]) -> None: ...

global___ListLifecyclePoliciesResponse = ListLifecyclePoliciesResponse

@typing.final
class CreateLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    repository_id: builtins.str
    """ID of the lifecycle policy repository."""
    name: builtins.str
    """Name of lifecycle policy."""
    description: builtins.str
    """Description of lifecycle policy."""
    status: yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy.Status.ValueType
    """Status of the lifecycle policy."""
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecycleRule]:
        """The rules of the lifecycle policy."""

    def __init__(
        self,
        *,
        repository_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy.Status.ValueType = ...,
        rules: collections.abc.Iterable[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecycleRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "repository_id", b"repository_id", "rules", b"rules", "status", b"status"]) -> None: ...

global___CreateLifecyclePolicyRequest = CreateLifecyclePolicyRequest

@typing.final
class UpdateLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    name: builtins.str
    """Name of lifecycle policy."""
    description: builtins.str
    """Description of lifecycle policy."""
    status: yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy.Status.ValueType
    """Status of the lifecycle policy."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the lifecycle policy resource are going to be updated."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecycleRule]:
        """The rules of the lifecycle policy."""

    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecyclePolicy.Status.ValueType = ...,
        rules: collections.abc.Iterable[yandex.cloud.containerregistry.v1.lifecycle_policy_pb2.LifecycleRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "lifecycle_policy_id", b"lifecycle_policy_id", "name", b"name", "rules", b"rules", "status", b"status", "update_mask", b"update_mask"]) -> None: ...

global___UpdateLifecyclePolicyRequest = UpdateLifecyclePolicyRequest

@typing.final
class DeleteLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___DeleteLifecyclePolicyRequest = DeleteLifecyclePolicyRequest

@typing.final
class CreateLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy resource that is being created."""
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___CreateLifecyclePolicyMetadata = CreateLifecyclePolicyMetadata

@typing.final
class UpdateLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy resource that is being updated."""
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___UpdateLifecyclePolicyMetadata = UpdateLifecyclePolicyMetadata

@typing.final
class DeleteLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy resource that is being deleted."""
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___DeleteLifecyclePolicyMetadata = DeleteLifecyclePolicyMetadata

@typing.final
class DryRunLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___DryRunLifecyclePolicyRequest = DryRunLifecyclePolicyRequest

@typing.final
class DryRunLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRY_RUN_LIFECYCLE_POLICY_RESULT_ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    dry_run_lifecycle_policy_result_id: builtins.str
    """ID of the dry run result of the lifecycle policy."""
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    def __init__(
        self,
        *,
        dry_run_lifecycle_policy_result_id: builtins.str = ...,
        lifecycle_policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dry_run_lifecycle_policy_result_id", b"dry_run_lifecycle_policy_result_id", "lifecycle_policy_id", b"lifecycle_policy_id"]) -> None: ...

global___DryRunLifecyclePolicyMetadata = DryRunLifecyclePolicyMetadata

@typing.final
class DryRunLifecyclePolicyResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRY_RUN_LIFECYCLE_POLICY_RESULT_ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    RUN_AT_FIELD_NUMBER: builtins.int
    AFFECTED_IMAGES_COUNT_FIELD_NUMBER: builtins.int
    dry_run_lifecycle_policy_result_id: builtins.str
    """ID of the dry run result of the lifecycle policy."""
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    affected_images_count: builtins.int
    """Count of affected images."""
    @property
    def run_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the getting result."""

    def __init__(
        self,
        *,
        dry_run_lifecycle_policy_result_id: builtins.str = ...,
        lifecycle_policy_id: builtins.str = ...,
        run_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        affected_images_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["run_at", b"run_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["affected_images_count", b"affected_images_count", "dry_run_lifecycle_policy_result_id", b"dry_run_lifecycle_policy_result_id", "lifecycle_policy_id", b"lifecycle_policy_id", "run_at", b"run_at"]) -> None: ...

global___DryRunLifecyclePolicyResult = DryRunLifecyclePolicyResult

@typing.final
class GetDryRunLifecyclePolicyResultRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRY_RUN_LIFECYCLE_POLICY_RESULT_ID_FIELD_NUMBER: builtins.int
    dry_run_lifecycle_policy_result_id: builtins.str
    """ID of the dry run result of the lifecycle policy."""
    def __init__(
        self,
        *,
        dry_run_lifecycle_policy_result_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dry_run_lifecycle_policy_result_id", b"dry_run_lifecycle_policy_result_id"]) -> None: ...

global___GetDryRunLifecyclePolicyResultRequest = GetDryRunLifecyclePolicyResultRequest

@typing.final
class ListDryRunLifecyclePolicyResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    lifecycle_policy_id: builtins.str
    """ID of the lifecycle policy."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns 
    a [ListDryRunLifecyclePolicyResultsResponse.next_page_token] that can be used to get 
    the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDryRunLifecyclePolicyResultsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters dry run results listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [LifecyclePolicy.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    order_by: builtins.str
    """Sorting the list by [DryRunLifecyclePolicyResult.run_at] and [DryRunLifecyclePolicyResult.affected_images_count] fields.
    The default sorting order is ascending.
    """
    def __init__(
        self,
        *,
        lifecycle_policy_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "lifecycle_policy_id", b"lifecycle_policy_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDryRunLifecyclePolicyResultsRequest = ListDryRunLifecyclePolicyResultsRequest

@typing.final
class ListDryRunLifecyclePolicyResultsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRY_RUN_LIFECYCLE_POLICY_RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDryRunLifecyclePolicyResultsRequest.page_size] use `next_page_token` as the value
    for the [ListDryRunLifecyclePolicyResultsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def dry_run_lifecycle_policy_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DryRunLifecyclePolicyResult]:
        """List of results of dry runs of a lifecycle policy."""

    def __init__(
        self,
        *,
        dry_run_lifecycle_policy_results: collections.abc.Iterable[global___DryRunLifecyclePolicyResult] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dry_run_lifecycle_policy_results", b"dry_run_lifecycle_policy_results", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDryRunLifecyclePolicyResultsResponse = ListDryRunLifecyclePolicyResultsResponse

@typing.final
class ListDryRunLifecyclePolicyResultAffectedImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRY_RUN_LIFECYCLE_POLICY_RESULT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    dry_run_lifecycle_policy_result_id: builtins.str
    """ID of the dry run result of the lifecycle policy"""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListDryRunLifecyclePolicyResultAffectedImagesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDryRunLifecyclePolicyResultAffectedImagesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters affected images listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [LifecyclePolicy.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    order_by: builtins.str
    """Sorting the list by [LifecyclePolicy.name] and [LifecyclePolicy.created_at] fields.
    The default sorting order is ascending.
    """
    def __init__(
        self,
        *,
        dry_run_lifecycle_policy_result_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dry_run_lifecycle_policy_result_id", b"dry_run_lifecycle_policy_result_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDryRunLifecyclePolicyResultAffectedImagesRequest = ListDryRunLifecyclePolicyResultAffectedImagesRequest

@typing.final
class ListDryRunLifecyclePolicyResultAffectedImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AFFECTED_IMAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDryRunLifecyclePolicyResultAffectedImagesRequest.page_size], use `next_page_token` as the value
    for the [ListDryRunLifecyclePolicyResultAffectedImagesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def affected_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.image_pb2.Image]:
        """List of affected images."""

    def __init__(
        self,
        *,
        affected_images: collections.abc.Iterable[yandex.cloud.containerregistry.v1.image_pb2.Image] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["affected_images", b"affected_images", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDryRunLifecyclePolicyResultAffectedImagesResponse = ListDryRunLifecyclePolicyResultAffectedImagesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ydb/v1/backup.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ydb/v1/backup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/ydb/v1/backup.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1bgoogle/type/dayofweek.proto\x1a\x1dyandex/cloud/validation.proto\"\xc2\x02\n\x0e\x42\x61\x63kupSchedule\x12I\n\x15\x64\x61ily_backup_schedule\x18\x01 \x01(\x0b\x32(.yandex.cloud.ydb.v1.DailyBackupScheduleH\x00\x12K\n\x16weekly_backup_schedule\x18\x02 \x01(\x0b\x32).yandex.cloud.ydb.v1.WeeklyBackupScheduleH\x00\x12Q\n\x19recurring_backup_schedule\x18\x04 \x01(\x0b\x32,.yandex.cloud.ydb.v1.RecurringBackupScheduleH\x00\x12\x35\n\x11next_execute_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"i\n\x17RecurringBackupSchedule\x12\x34\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x18\n\nrecurrence\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"}\n\x18\x44\x61ysOfWeekBackupSchedule\x12-\n\x04\x64\x61ys\x18\x01 \x03(\x0e\x32\x16.google.type.DayOfWeekB\x07\x82\xc8\x31\x03\x31-7\x12\x32\n\x0c\x65xecute_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\"d\n\x14WeeklyBackupSchedule\x12L\n\x0c\x64\x61ys_of_week\x18\x01 \x03(\x0b\x32-.yandex.cloud.ydb.v1.DaysOfWeekBackupScheduleB\x07\x82\xc8\x31\x03\x31-7\"I\n\x13\x44\x61ilyBackupSchedule\x12\x32\n\x0c\x65xecute_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\"\xfe\x04\n\x0e\x42\x61\x63kupSettings\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12<\n\x0f\x62\x61\x63kup_schedule\x18\x03 \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSchedule\x12\x36\n\x13\x62\x61\x63kup_time_to_live\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x0csource_paths\x18\x05 \x03(\tB\t\x82\xc8\x31\x05<=256\x12*\n\x17source_paths_to_exclude\x18\x06 \x03(\tB\t\x82\xc8\x31\x05<=256\x12\x36\n\x04type\x18\x07 \x01(\x0e\x32(.yandex.cloud.ydb.v1.BackupSettings.Type\x12G\n\rstorage_class\x18\x08 \x01(\x0e\x32\x30.yandex.cloud.ydb.v1.BackupSettings.StorageClass\"2\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x08\n\x04USER\x10\x02\"\xba\x01\n\x0cStorageClass\x12\x1d\n\x19STORAGE_CLASS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x16\n\x12REDUCED_REDUNDANCY\x10\x02\x12\x0f\n\x0bSTANDARD_IA\x10\x03\x12\x0e\n\nONEZONE_IA\x10\x04\x12\x17\n\x13INTELLIGENT_TIERING\x10\x05\x12\x0b\n\x07GLACIER\x10\x06\x12\x10\n\x0c\x44\x45\x45P_ARCHIVE\x10\x07\x12\x0c\n\x08OUTPOSTS\x10\x08\"L\n\x0c\x42\x61\x63kupConfig\x12<\n\x0f\x62\x61\x63kup_settings\x18\x01 \x03(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\"\xaa\x04\n\x06\x42\x61\x63kup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x06status\x18\t \x01(\x0e\x32\".yandex.cloud.ydb.v1.Backup.Status\x12<\n\x0f\x62\x61\x63kup_settings\x18\n \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\x12.\n\x04type\x18\x0b \x01(\x0e\x32 .yandex.cloud.ydb.v1.Backup.Type\x12\x0c\n\x04size\x18\x0c \x01(\x03\"S\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\r\n\tCANCELLED\x10\x04\"2\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x08\n\x04USER\x10\x02\x42V\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.backup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _globals['_BACKUPSCHEDULE'].oneofs_by_name['policy']._loaded_options = None
  _globals['_BACKUPSCHEDULE'].oneofs_by_name['policy']._serialized_options = b'\300\3011\001'
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['start_time']._loaded_options = None
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['start_time']._serialized_options = b'\350\3071\001'
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['recurrence']._loaded_options = None
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['recurrence']._serialized_options = b'\350\3071\001'
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['days']._loaded_options = None
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['days']._serialized_options = b'\202\3101\0031-7'
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['execute_time']._loaded_options = None
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['execute_time']._serialized_options = b'\350\3071\001'
  _globals['_WEEKLYBACKUPSCHEDULE'].fields_by_name['days_of_week']._loaded_options = None
  _globals['_WEEKLYBACKUPSCHEDULE'].fields_by_name['days_of_week']._serialized_options = b'\202\3101\0031-7'
  _globals['_DAILYBACKUPSCHEDULE'].fields_by_name['execute_time']._loaded_options = None
  _globals['_DAILYBACKUPSCHEDULE'].fields_by_name['execute_time']._serialized_options = b'\350\3071\001'
  _globals['_BACKUPSETTINGS'].fields_by_name['name']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['name']._serialized_options = b'\212\3101\005<=256'
  _globals['_BACKUPSETTINGS'].fields_by_name['description']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths']._serialized_options = b'\202\3101\005<=256'
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths_to_exclude']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths_to_exclude']._serialized_options = b'\202\3101\005<=256'
  _globals['_BACKUPSCHEDULE']._serialized_start=212
  _globals['_BACKUPSCHEDULE']._serialized_end=534
  _globals['_RECURRINGBACKUPSCHEDULE']._serialized_start=536
  _globals['_RECURRINGBACKUPSCHEDULE']._serialized_end=641
  _globals['_DAYSOFWEEKBACKUPSCHEDULE']._serialized_start=643
  _globals['_DAYSOFWEEKBACKUPSCHEDULE']._serialized_end=768
  _globals['_WEEKLYBACKUPSCHEDULE']._serialized_start=770
  _globals['_WEEKLYBACKUPSCHEDULE']._serialized_end=870
  _globals['_DAILYBACKUPSCHEDULE']._serialized_start=872
  _globals['_DAILYBACKUPSCHEDULE']._serialized_end=945
  _globals['_BACKUPSETTINGS']._serialized_start=948
  _globals['_BACKUPSETTINGS']._serialized_end=1586
  _globals['_BACKUPSETTINGS_TYPE']._serialized_start=1347
  _globals['_BACKUPSETTINGS_TYPE']._serialized_end=1397
  _globals['_BACKUPSETTINGS_STORAGECLASS']._serialized_start=1400
  _globals['_BACKUPSETTINGS_STORAGECLASS']._serialized_end=1586
  _globals['_BACKUPCONFIG']._serialized_start=1588
  _globals['_BACKUPCONFIG']._serialized_end=1664
  _globals['_BACKUP']._serialized_start=1667
  _globals['_BACKUP']._serialized_end=2221
  _globals['_BACKUP_STATUS']._serialized_start=2086
  _globals['_BACKUP_STATUS']._serialized_end=2169
  _globals['_BACKUP_TYPE']._serialized_start=1347
  _globals['_BACKUP_TYPE']._serialized_end=1397
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.stream_pb2
import yandex.cloud.video.v1.stream_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class StreamServiceStub:
    """Stream management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.GetStreamRequest,
        yandex.cloud.video.v1.stream_pb2.Stream,
    ]
    """Get the specific stream."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.ListStreamsRequest,
        yandex.cloud.video.v1.stream_service_pb2.ListStreamsResponse,
    ]
    """List streams for channel."""

    BatchGet: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsRequest,
        yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsResponse,
    ]
    """Batch get streams for channel."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.CreateStreamRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create stream."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.UpdateStreamRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update stream."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.DeleteStreamRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete stream."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.BatchDeleteStreamsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete streams."""

    PerformAction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.PerformStreamActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the stream."""

class StreamServiceAsyncStub:
    """Stream management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.GetStreamRequest,
        yandex.cloud.video.v1.stream_pb2.Stream,
    ]
    """Get the specific stream."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.ListStreamsRequest,
        yandex.cloud.video.v1.stream_service_pb2.ListStreamsResponse,
    ]
    """List streams for channel."""

    BatchGet: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsRequest,
        yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsResponse,
    ]
    """Batch get streams for channel."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.CreateStreamRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create stream."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.UpdateStreamRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update stream."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.DeleteStreamRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete stream."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.BatchDeleteStreamsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete streams."""

    PerformAction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_service_pb2.PerformStreamActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the stream."""

class StreamServiceServicer(metaclass=abc.ABCMeta):
    """Stream management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.GetStreamRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_pb2.Stream, collections.abc.Awaitable[yandex.cloud.video.v1.stream_pb2.Stream]]:
        """Get the specific stream."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.ListStreamsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_service_pb2.ListStreamsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.stream_service_pb2.ListStreamsResponse]]:
        """List streams for channel."""

    @abc.abstractmethod
    def BatchGet(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.stream_service_pb2.BatchGetStreamsResponse]]:
        """Batch get streams for channel."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.CreateStreamRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create stream."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.UpdateStreamRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update stream."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.DeleteStreamRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete stream."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.BatchDeleteStreamsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Batch delete streams."""

    @abc.abstractmethod
    def PerformAction(
        self,
        request: yandex.cloud.video.v1.stream_service_pb2.PerformStreamActionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Perform an action on the stream."""

def add_StreamServiceServicer_to_server(servicer: StreamServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/devices/v1/device.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/devices/v1/device.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/iot/devices/v1/device.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc1\x04\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bregistry_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\rtopic_aliases\x18\x06 \x03(\x0b\x32\x35.yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry\x12:\n\x06status\x18\x07 \x01(\x0e\x32*.yandex.cloud.iot.devices.v1.Device.Status\x12J\n\x0fmonitoring_data\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.iot.devices.v1.DeviceMonitoringData\x12?\n\x06labels\x18\t \x03(\x0b\x32/.yandex.cloud.iot.devices.v1.Device.LabelsEntry\x1a\x33\n\x11TopicAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x85\x01\n\x11\x44\x65viceCertificate\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"_\n\x0e\x44\x65vicePassword\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc8\x02\n\x14\x44\x65viceMonitoringData\x12\x14\n\x0clast_auth_ip\x18\x01 \x01(\t\x12\x32\n\x0elast_auth_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_pub_activity_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_sub_activity_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_online_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14last_disconnect_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*!\n\nDeviceView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x42j\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.device_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _globals['_DEVICE_TOPICALIASESENTRY']._loaded_options = None
  _globals['_DEVICE_TOPICALIASESENTRY']._serialized_options = b'8\001'
  _globals['_DEVICE_LABELSENTRY']._loaded_options = None
  _globals['_DEVICE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICEVIEW']._serialized_start=1250
  _globals['_DEVICEVIEW']._serialized_end=1283
  _globals['_DEVICE']._serialized_start=107
  _globals['_DEVICE']._serialized_end=684
  _globals['_DEVICE_TOPICALIASESENTRY']._serialized_start=512
  _globals['_DEVICE_TOPICALIASESENTRY']._serialized_end=563
  _globals['_DEVICE_LABELSENTRY']._serialized_start=565
  _globals['_DEVICE_LABELSENTRY']._serialized_end=610
  _globals['_DEVICE_STATUS']._serialized_start=612
  _globals['_DEVICE_STATUS']._serialized_end=684
  _globals['_DEVICECERTIFICATE']._serialized_start=687
  _globals['_DEVICECERTIFICATE']._serialized_end=820
  _globals['_DEVICEPASSWORD']._serialized_start=822
  _globals['_DEVICEPASSWORD']._serialized_end=917
  _globals['_DEVICEMONITORINGDATA']._serialized_start=920
  _globals['_DEVICEMONITORINGDATA']._serialized_end=1248
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2
import yandex.cloud.loadtesting.api.v1.test.imbalance_point_pb2
import yandex.cloud.loadtesting.api.v1.test.status_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Summary(google.protobuf.message.Message):
    """Process of test and some results"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    IS_FINISHED_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    IMBALANCE_POINT_FIELD_NUMBER: builtins.int
    ASSIGNED_AGENT_ID_FIELD_NUMBER: builtins.int
    ARTIFACTS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.loadtesting.api.v1.test.status_pb2.Status.ValueType
    """Status of the test."""
    created_by: builtins.str
    """UA or SA that created the test."""
    is_finished: builtins.bool
    """Indicates whether the test is finished."""
    error: builtins.str
    """Error message."""
    assigned_agent_id: builtins.str
    """ID of the agent that executed the test."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Test start timestamp.

        Empty if the test has not been started yet.
        """

    @property
    def finished_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Test finish timestamp.

        Empty if the test has not been finished yet.
        """

    @property
    def imbalance_point(self) -> yandex.cloud.loadtesting.api.v1.test.imbalance_point_pb2.ImbalancePoint:
        """Detected imbalance point.

        Contains information about a state at the moment it has been
        [auto-stopped](/docs/load-testing/concepts/auto-stop).

        Empty if no auto-stop occured.
        """

    @property
    def artifacts(self) -> yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2.FilePointer:
        """Test output artifacts.

        Link to the artifacts output target containing `.log` and other files collected
        during test execution.
        """

    def __init__(
        self,
        *,
        status: yandex.cloud.loadtesting.api.v1.test.status_pb2.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finished_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        is_finished: builtins.bool = ...,
        error: builtins.str = ...,
        imbalance_point: yandex.cloud.loadtesting.api.v1.test.imbalance_point_pb2.ImbalancePoint | None = ...,
        assigned_agent_id: builtins.str = ...,
        artifacts: yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2.FilePointer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["artifacts", b"artifacts", "created_at", b"created_at", "finished_at", b"finished_at", "imbalance_point", b"imbalance_point", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["artifacts", b"artifacts", "assigned_agent_id", b"assigned_agent_id", "created_at", b"created_at", "created_by", b"created_by", "error", b"error", "finished_at", b"finished_at", "imbalance_point", b"imbalance_point", "is_finished", b"is_finished", "started_at", b"started_at", "status", b"status"]) -> None: ...

global___Summary = Summary



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourceGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    IS_USER_DEFINED_FIELD_NUMBER: builtins.int
    CONCURRENCY_FIELD_NUMBER: builtins.int
    CPU_RATE_LIMIT_FIELD_NUMBER: builtins.int
    MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    MEMORY_SHARED_QUOTA_FIELD_NUMBER: builtins.int
    MEMORY_SPILL_RATIO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def is_user_defined(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to CONCURRENCY from gp resource group parameter"""

    @property
    def cpu_rate_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to CPU_RATE_LIMIT from gp resource group parameter"""

    @property
    def memory_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to MEMORY_LIMIT from gp resource group parameter"""

    @property
    def memory_shared_quota(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to MEMORY_SHARED_QUOTA from gp resource group parameter"""

    @property
    def memory_spill_ratio(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to MEMORY_SPILL_RATIO from gp resource group parameter"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        is_user_defined: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        cpu_rate_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        memory_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        memory_shared_quota: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        memory_spill_ratio: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["concurrency", b"concurrency", "cpu_rate_limit", b"cpu_rate_limit", "is_user_defined", b"is_user_defined", "memory_limit", b"memory_limit", "memory_shared_quota", b"memory_shared_quota", "memory_spill_ratio", b"memory_spill_ratio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["concurrency", b"concurrency", "cpu_rate_limit", b"cpu_rate_limit", "is_user_defined", b"is_user_defined", "memory_limit", b"memory_limit", "memory_shared_quota", b"memory_shared_quota", "memory_spill_ratio", b"memory_spill_ratio", "name", b"name"]) -> None: ...

global___ResourceGroup = ResourceGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/channel.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/channel.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/video/v1/channel.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe6\x02\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x06labels\x18\xc8\x01 \x03(\x0b\x32*.yandex.cloud.video.v1.Channel.LabelsEntry\x12\x39\n\x08settings\x18\xc9\x01 \x01(\x0b\x32&.yandex.cloud.video.v1.ChannelSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x64J\x05\x08\x66\x10\xc8\x01\"\xae\x01\n\x0f\x43hannelSettings\x12\x43\n\radvertisement\x18\x01 \x01(\x0b\x32,.yandex.cloud.video.v1.AdvertisementSettings\x12P\n\x14referer_verification\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.video.v1.RefererVerificationSettingsJ\x04\x08\x02\x10\x03\"\xc0\x01\n\x15\x41\x64vertisementSettings\x12R\n\ryandex_direct\x18\x64 \x01(\x0b\x32\x39.yandex.cloud.video.v1.AdvertisementSettings.YandexDirectH\x00\x1a\x41\n\x0cYandexDirect\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x0f\n\x07page_id\x18\x02 \x01(\x03\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\x03\x42\n\n\x08providerJ\x04\x08\x01\x10\x64\"\x9c\x01\n\x1bRefererVerificationSettings\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12m\n\x0f\x61llowed_domains\x18\x02 \x03(\tBT\xf2\xc7\x31>^(?:\\*\\.)?(?:[a-zA-Z0-9-]*\\.)+[a-zA-Z]{2,}$|^\\*\\.[a-zA-Z]{2,}$\x82\xc8\x31\x05<=100\x8a\xc8\x31\x05\x34-255B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.channel_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_CHANNEL_LABELSENTRY']._loaded_options = None
  _globals['_CHANNEL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_REFERERVERIFICATIONSETTINGS'].fields_by_name['allowed_domains']._loaded_options = None
  _globals['_REFERERVERIFICATIONSETTINGS'].fields_by_name['allowed_domains']._serialized_options = b'\362\3071>^(?:\\*\\.)?(?:[a-zA-Z0-9-]*\\.)+[a-zA-Z]{2,}$|^\\*\\.[a-zA-Z]{2,}$\202\3101\005<=100\212\3101\0054-255'
  _globals['_CHANNEL']._serialized_start=127
  _globals['_CHANNEL']._serialized_end=485
  _globals['_CHANNEL_LABELSENTRY']._serialized_start=427
  _globals['_CHANNEL_LABELSENTRY']._serialized_end=472
  _globals['_CHANNELSETTINGS']._serialized_start=488
  _globals['_CHANNELSETTINGS']._serialized_end=662
  _globals['_ADVERTISEMENTSETTINGS']._serialized_start=665
  _globals['_ADVERTISEMENTSETTINGS']._serialized_end=857
  _globals['_ADVERTISEMENTSETTINGS_YANDEXDIRECT']._serialized_start=774
  _globals['_ADVERTISEMENTSETTINGS_YANDEXDIRECT']._serialized_end=839
  _globals['_REFERERVERIFICATIONSETTINGS']._serialized_start=860
  _globals['_REFERERVERIFICATIONSETTINGS']._serialized_end=1016
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetProductInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    product_instance_id: builtins.str
    def __init__(
        self,
        *,
        product_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["product_instance_id", b"product_instance_id"]) -> None: ...

global___GetProductInstanceRequest = GetProductInstanceRequest

@typing.final
class ClaimProductInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    token: builtins.str
    resource_id: builtins.str
    @property
    def resource_info(self) -> yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2.SaasInfo: ...
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        resource_id: builtins.str = ...,
        resource_info: yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2.SaasInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "resource_info", b"resource_info", "token", b"token"]) -> None: ...

global___ClaimProductInstanceRequest = ClaimProductInstanceRequest

@typing.final
class ClaimProductInstanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    LICENSE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    product_id: builtins.str
    product_instance_id: builtins.str
    license_instance_id: builtins.str
    def __init__(
        self,
        *,
        product_id: builtins.str = ...,
        product_instance_id: builtins.str = ...,
        license_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["license_instance_id", b"license_instance_id", "product_id", b"product_id", "product_instance_id", b"product_instance_id"]) -> None: ...

global___ClaimProductInstanceMetadata = ClaimProductInstanceMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iot.broker.v1.broker_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBrokerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to return.

    To get a broker ID make a [BrokerService.List] request.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___GetBrokerRequest = GetBrokerRequest

@typing.final
class ListBrokersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list brokers in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a [ListBrokersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListBrokersResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBrokersRequest = ListBrokersRequest

@typing.final
class ListBrokersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListBrokersRequest.page_size], use `next_page_token` as the value
    for the [ListBrokersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def brokers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iot.broker.v1.broker_pb2.Broker]:
        """List of brokers."""

    def __init__(
        self,
        *,
        brokers: collections.abc.Iterable[yandex.cloud.iot.broker.v1.broker_pb2.Broker] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["brokers", b"brokers", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBrokersResponse = ListBrokersResponse

@typing.final
class CreateBrokerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Certificate(google.protobuf.message.Message):
        """Specification of a broker certificate."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
        certificate_data: builtins.str
        """Public part of the broker certificate."""
        def __init__(
            self,
            *,
            certificate_data: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["certificate_data", b"certificate_data"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CERTIFICATES_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a broker in.

    To get a folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the broker. The name must be unique within the folder."""
    description: builtins.str
    """Description of the broker."""
    password: builtins.str
    """Broker passwords.

    The password must contain at least three character categories among the following: upper case latin, lower case latin, numbers and special symbols.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateBrokerRequest.Certificate]:
        """Broker certificates."""

    @property
    def log_options(self) -> yandex.cloud.iot.broker.v1.broker_pb2.LogOptions:
        """Options for logging broker events"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        certificates: collections.abc.Iterable[global___CreateBrokerRequest.Certificate] | None = ...,
        password: builtins.str = ...,
        log_options: yandex.cloud.iot.broker.v1.broker_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificates", b"certificates", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "password", b"password"]) -> None: ...

global___CreateBrokerRequest = CreateBrokerRequest

@typing.final
class CreateBrokerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker that is being created."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___CreateBrokerMetadata = CreateBrokerMetadata

@typing.final
class UpdateBrokerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BROKER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to update.

    To get a broker ID make a [BrokerService.List] request.
    """
    name: builtins.str
    """Name of the broker. The name must be unique within the folder."""
    description: builtins.str
    """Description of the broker."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the broker are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def log_options(self) -> yandex.cloud.iot.broker.v1.broker_pb2.LogOptions:
        """Options for logging broker events"""

    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        log_options: yandex.cloud.iot.broker.v1.broker_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["log_options", b"log_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "description", b"description", "labels", b"labels", "log_options", b"log_options", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateBrokerRequest = UpdateBrokerRequest

@typing.final
class UpdateBrokerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker that is being updated."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___UpdateBrokerMetadata = UpdateBrokerMetadata

@typing.final
class DeleteBrokerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to delete.

    To get a broker ID make a [BrokerService.List] request.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___DeleteBrokerRequest = DeleteBrokerRequest

@typing.final
class DeleteBrokerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker that is being deleted."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___DeleteBrokerMetadata = DeleteBrokerMetadata

@typing.final
class ListBrokerCertificatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to list certificates for."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___ListBrokerCertificatesRequest = ListBrokerCertificatesRequest

@typing.final
class ListBrokerCertificatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iot.broker.v1.broker_pb2.BrokerCertificate]:
        """List of certificates for the specified broker."""

    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[yandex.cloud.iot.broker.v1.broker_pb2.BrokerCertificate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificates", b"certificates"]) -> None: ...

global___ListBrokerCertificatesResponse = ListBrokerCertificatesResponse

@typing.final
class AddBrokerCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker for which the certificate is being added.

    To get a broker ID make a [BrokerService.List] request.
    """
    certificate_data: builtins.str
    """Public part of the certificate that is being added."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        certificate_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "certificate_data", b"certificate_data"]) -> None: ...

global___AddBrokerCertificateRequest = AddBrokerCertificateRequest

@typing.final
class AddBrokerCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker certificate that is being added."""
    fingerprint: builtins.str
    """Fingerprint of the certificate that is being added."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "fingerprint", b"fingerprint"]) -> None: ...

global___AddBrokerCertificateMetadata = AddBrokerCertificateMetadata

@typing.final
class DeleteBrokerCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to delete a certificate for.

    To get a broker ID make a [BrokerService.List] request.
    """
    fingerprint: builtins.str
    """Fingerprint of the certificate that is being deleted."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "fingerprint", b"fingerprint"]) -> None: ...

global___DeleteBrokerCertificateRequest = DeleteBrokerCertificateRequest

@typing.final
class DeleteBrokerCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of a broker for which the certificate is being delete."""
    fingerprint: builtins.str
    """Fingerprint of the certificate to deleted."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "fingerprint", b"fingerprint"]) -> None: ...

global___DeleteBrokerCertificateMetadata = DeleteBrokerCertificateMetadata

@typing.final
class ListBrokerPasswordsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to list passwords in.

    To get a broker ID make a [BrokerService.List] request.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id"]) -> None: ...

global___ListBrokerPasswordsRequest = ListBrokerPasswordsRequest

@typing.final
class ListBrokerPasswordsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORDS_FIELD_NUMBER: builtins.int
    @property
    def passwords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iot.broker.v1.broker_pb2.BrokerPassword]:
        """List of passwords for the specified broker."""

    def __init__(
        self,
        *,
        passwords: collections.abc.Iterable[yandex.cloud.iot.broker.v1.broker_pb2.BrokerPassword] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["passwords", b"passwords"]) -> None: ...

global___ListBrokerPasswordsResponse = ListBrokerPasswordsResponse

@typing.final
class AddBrokerPasswordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to add a password for.

    To get a broker ID make a [BrokerService.List] request.
    """
    password: builtins.str
    """Passwords for the broker.

    The password must contain at least three character categories among the following: upper case latin, lower case latin, numbers and special symbols.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "password", b"password"]) -> None: ...

global___AddBrokerPasswordRequest = AddBrokerPasswordRequest

@typing.final
class AddBrokerPasswordMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    PASSWORD_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker for which the password is being added."""
    password_id: builtins.str
    """ID of a password that is being added."""
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        password_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "password_id", b"password_id"]) -> None: ...

global___AddBrokerPasswordMetadata = AddBrokerPasswordMetadata

@typing.final
class DeleteBrokerPasswordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    PASSWORD_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to delete a password for.

    To get a broker ID make a [BrokerService.List] request.
    """
    password_id: builtins.str
    """ID of the password to delete.

    To get a password ID make a [BrokerService.ListPasswords] request.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        password_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "password_id", b"password_id"]) -> None: ...

global___DeleteBrokerPasswordRequest = DeleteBrokerPasswordRequest

@typing.final
class DeleteBrokerPasswordMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    PASSWORD_ID_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of a broker for which the password is being delete."""
    password_id: builtins.str
    """ID of the password to delete.

    To get a password ID make a [BrokerService.ListPasswords] request.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        password_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "password_id", b"password_id"]) -> None: ...

global___DeleteBrokerPasswordMetadata = DeleteBrokerPasswordMetadata

@typing.final
class ListBrokerOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a [ListBrokerOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListBrokerOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on [Broker.name] field.
    """
    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBrokerOperationsRequest = ListBrokerOperationsRequest

@typing.final
class ListBrokerOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListBrokerOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListBrokerOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified broker."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListBrokerOperationsResponse = ListBrokerOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/node_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/node_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/datasphere/v1/node_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\"b\n\x14NodeExecutionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12&\n\x05input\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x15NodeExecutionResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\x15\x41liasExecutionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12&\n\x05input\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"A\n\x16\x41liasExecutionResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xe1\x02\n\x0bNodeService\x12\xa1\x01\n\x07\x45xecute\x12\x30.yandex.cloud.datasphere.v1.NodeExecutionRequest\x1a\x31.yandex.cloud.datasphere.v1.NodeExecutionResponse\"1\x82\xd3\xe4\x93\x02+\"&/datasphere/v1/nodes/{node_id}:execute:\x01*\x12\xad\x01\n\x0c\x45xecuteAlias\x12\x31.yandex.cloud.datasphere.v1.AliasExecutionRequest\x1a\x32.yandex.cloud.datasphere.v1.AliasExecutionResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/datasphere/v1/aliases/{alias_name}:execute:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.node_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_NODESERVICE'].methods_by_name['Execute']._loaded_options = None
  _globals['_NODESERVICE'].methods_by_name['Execute']._serialized_options = b'\202\323\344\223\002+\"&/datasphere/v1/nodes/{node_id}:execute:\001*'
  _globals['_NODESERVICE'].methods_by_name['ExecuteAlias']._loaded_options = None
  _globals['_NODESERVICE'].methods_by_name['ExecuteAlias']._serialized_options = b'\202\323\344\223\0020\"+/datasphere/v1/aliases/{alias_name}:execute:\001*'
  _globals['_NODEEXECUTIONREQUEST']._serialized_start=137
  _globals['_NODEEXECUTIONREQUEST']._serialized_end=235
  _globals['_NODEEXECUTIONRESPONSE']._serialized_start=237
  _globals['_NODEEXECUTIONRESPONSE']._serialized_end=301
  _globals['_ALIASEXECUTIONREQUEST']._serialized_start=303
  _globals['_ALIASEXECUTIONREQUEST']._serialized_end=405
  _globals['_ALIASEXECUTIONRESPONSE']._serialized_start=407
  _globals['_ALIASEXECUTIONRESPONSE']._serialized_end=472
  _globals['_NODESERVICE']._serialized_start=475
  _globals['_NODESERVICE']._serialized_end=828
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    user_account_id: builtins.str
    """ID of the UserAccount resource to return."""
    def __init__(
        self,
        *,
        user_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_account_id", b"user_account_id"]) -> None: ...

global___GetUserAccountRequest = GetUserAccountRequest
